==> qtjambi-remoteobjects-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiRemoteObjects/QRemoteObjectNode_shell.h <==
#ifndef QREMOTEOBJECTNODE_SHELL_H
#define QREMOTEOBJECTNODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpair.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectNode_shell : public QRemoteObjectNode, public QtJambiShellInterface
{
public:
    QRemoteObjectNode_shell(QObject* parent0 = nullptr);
    QRemoteObjectNode_shell(const QUrl& registryAddress0, QObject* parent1 = nullptr);
    ~QRemoteObjectNode_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setName(const QString& name0) override;
    bool setRegistryUrl(const QUrl& registryAddress0) override;
    void timerEvent(QTimerEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectNode_access : public QRemoteObjectNode
{
    void __qt_setName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_setRegistryUrl_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID registryAddress0);
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QREMOTEOBJECTNODE_SHELL_H

==> qtjambi-remoteobjects-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiRemoteObjects/QRemoteObjectNode_shell.h <==
#ifndef QREMOTEOBJECTNODE_SHELL_H
#define QREMOTEOBJECTNODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectNode_shell : public QRemoteObjectNode, public QtJambiShellInterface
{
public:
    QRemoteObjectNode_shell(QObject* parent0 = nullptr);
    QRemoteObjectNode_shell(const QUrl& registryAddress0, QObject* parent1 = nullptr);
    ~QRemoteObjectNode_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setName(const QString& name0) override;
    bool setRegistryUrl(const QUrl& registryAddress0) override;
    void timerEvent(QTimerEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectNode_access : public QRemoteObjectNode
{
    void __qt_setName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_setRegistryUrl_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID registryAddress0);
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QREMOTEOBJECTNODE_SHELL_H
